@@ -22,7 +22,7 @@ def bs(byte_array):
     return ''.join([chr(c) for c in byte_array])
 
 DEBUG = False
-__version__ = '0.4.0'
+__version__ = '0.4.1'
 apilevel = '2.0'
 threadsafety = 1
 paramstyle = 'qmark'
@@ -631,9 +631,10 @@ class cursor:
             self.connection._op_execute(self.stmt_handle, params)
             try:
                 (h, oid, buf) = self.connection._op_response()
-            except OperationalError as o:
-                if 335544665 in o.gds_codes:
-                    raise IntegrityError(o.message, o.gds_codes, o.sql_code)
+            except OperationalError:
+                e = sys.exc_info()[1]
+                if 335544665 in e.gds_codes:
+                    raise IntegrityError(e.message, e.gds_codes, e.sql_code)
             self.rows = None
 
     def executemany(self, query, seq_of_params):
@@ -1165,15 +1166,22 @@ class BaseConnect:
                 self.hostname = host
                 self.filename = dsn
             else:
-                self.hostname = dsn[:i]
+                hostport = dsn[:i]
                 self.filename = dsn[i+1:]
+                i = hostport.find('/')
+                if i < 0:
+                    self.hostname = hostport
+                    self.port = port
+                else:
+                    self.hostname = hostport[:i]
+                    self.port = int(hostport[i+1:])
         else:
             self.hostname = host
             self.filename = database
+            self.port = port
         self.user = user
         self.password = password
         self.charset = charset
-        self.port = port
         self.cursor_set = set()
         self.isolation_level = ISOLATION_LEVEL_READ_COMMITED
 
